@@ -3,7 +3,7 @@ version = "1.34.0"
 # tools
 dblatex = ''
 fop = ''
-pkg_config = '/usr/bin/x86_64-pc-msys-pkg-config'
+pkg_config = '/usr/bin/x86_64-pc-cygwin-pkg-config'
 xsltproc = '/usr/bin/xsltproc'
 
 # configured directories
